enablePeephole property
Whether to enable peephole optimization during compilation.
When enabled, redundant instructions are removed from the bytecode.
Defaults to true.
Implementation
final bool enablePeephole;
Whether to enable peephole optimization during compilation.
When enabled, redundant instructions are removed from the bytecode.
Defaults to true.
final bool enablePeephole;