stripDebug property

bool stripDebug
final

Whether to strip debug information from the compiled bytecode.

When enabled, the resulting bytecode is smaller but stack traces will not contain line numbers. Defaults to false.

Implementation

final bool stripDebug;